@@ -1,5 +1,5 @@
 package PostgreSQL::PLPerl::Call;
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 
 =head1 NAME
 
@@ -7,7 +7,7 @@ PostgreSQL::PLPerl::Call - Simple interface for calling SQL functions from Postg
 
 =head1 VERSION
 
-version 1.003
+version 1.004
 
 =head1 SYNOPSIS
 
@@ -125,10 +125,9 @@ For example:
     $seqn = SP->nextval($sequence_name);
 
 Using this form you can't easily specify a schema name or argument types, and
-you can't call variadic functions.
-
-If cases where a signature is needed you might get a somewhat confusing error
-message. For example:
+you can't call variadic functions. (For various technical reasons.)
+In cases where a signature is needed, like variadic or polymorphic functions,
+you might get a somewhat confusing error message. For example:
 
     SP->generate_series(10,20);
 
@@ -221,7 +220,7 @@ Tim Bunce L<http://www.tim.bunce.name>
 Copyright (c) Tim Bunce, Ireland, 2010. All rights reserved.
 You may use and distribute on the same terms as Perl 5.10.1.
 
-With thanks to TigerLead.com for sponsoring development.
+With thanks to L<http://www.TigerLead.com> for sponsoring development.
 
 =cut
 
@@ -239,7 +238,7 @@ our $debug = 0;
 # encapsulated package to provide an AUTOLOAD interface to call()
 use constant SP => do { 
     package PostgreSQL::PLPerl::Call::SP;
-our $VERSION = '1.003';
+our $VERSION = '1.004';
 
     sub AUTOLOAD {
         #(my $function = our $AUTOLOAD) =~ s/.*:://;
